@@ -2,6 +2,11 @@ require 'minitest/autorun'
 require 'marcel'
 require 'pathname'
 
+begin
+  require "debug"
+rescue StandardError, LoadError
+end
+
 class Marcel::TestCase < Minitest::Test
   class << self
     def setup(&block)
@@ -41,7 +46,7 @@ class Marcel::TestCase < Minitest::Test
   end
 
   def files(name)
-    Pathname.new fixture_path(name)
+    self.class.files(name)
   end
 
   def fixture_path(name)
